@@ -31,14 +31,22 @@ def getCopyObjectsUID(REQUEST):
     op, mdatas = CopySupport._cb_decode(cp)
     return {'op':op, 'url': ['/'.join(a) for a in mdatas][0]}
 
-def listQueryTopicCriteria(topic):
+def listBaseQueryTopicCriteria(topic):
     calendar = ISolgemaFullcalendarProperties(aq_inner(topic), None)
     li = []
     for criteria in topic.listCriteria():
-        if criteria.meta_type=='ATPortalTypeCriterion' and len(criteria.getCriteriaItems()[0][1])>1:
+        if criteria.meta_type=='ATPortalTypeCriterion' and len(criteria.getCriteriaItems()[0][1])>0:
             li.append(criteria)
-        if criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion'] and len(criteria.getCriteriaItems()[0][1]['query'])>1:
+        if criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion'] and criteria.getCriteriaItems() and len(criteria.getCriteriaItems()[0])>1 and len(criteria.getCriteriaItems()[0][1]['query'])>0:
             li.append(criteria)
+    return li
+
+def listQueryTopicCriteria(topic):
+    calendar = ISolgemaFullcalendarProperties(aq_inner(topic), None)
+    li = listBaseQueryTopicCriteria(topic)
+    for criteria in li:
+        if criteria.meta_type=='ATPortalTypeCriterion' and len(criteria.getCriteriaItems()[0][1])==1:
+            li.remove(criteria)
     if hasattr(calendar, 'availableCriterias') and getattr(calendar, 'availableCriterias', None) != None:
         li = [a for a in li if a.Field() in calendar.availableCriterias]
     return li
@@ -135,7 +143,7 @@ def getColorIndex(context, request, eventPath=None, brain=None):
     catalog = getToolByName(context, 'portal_catalog')
     if not brain:
         if not eventPath:
-            raise ValueError(u'Use must provide eventPath or brain')
+            raise ValueError(u'You must provide eventPath or brain')
         brain = catalog.searchResults(path=eventPath)[0]
     selectedItems = getCookieItems(request, criteriaItems['name'])
     if not selectedItems:
@@ -148,6 +156,7 @@ def getColorIndex(context, request, eventPath=None, brain=None):
         for val in brainVal:
             if criteriaItems['values'].count(val) != 0 and val in selectedItems:
                 colorIndex = ' colorIndex-'+str(criteriaItems['values'].index(val))
+                colorIndex += ' '+criteriaItems['name']+'colorIndex-'+str(criteriaItems['values'].index(val))
                 break
     return colorIndex
 
@@ -335,7 +344,7 @@ class SolgemaFullcalendarEvents(BrowserView):
         for criteria in self.context.listCriteria():
             if criteria.meta_type not in ['ATSelectionCriterion', 'ATListCriterion', 'ATSortCriterion', 'ATPortalTypeCriterion'] and criteria.Field():
                 args[criteria.Field()] = query[criteria.Field()]
-            elif criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion']:
+            elif criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion'] and criteria.getCriteriaItems() and len(criteria.getCriteriaItems()[0])>1 and len(criteria.getCriteriaItems()[0][1]['query'])>0:
                 items = getCookieItems(self.request, criteria.Field())
                 if items and criteria in topicCriteria:
                     if 'undefined' in items:
@@ -353,46 +362,56 @@ class SolgemaFullcalendarEvents(BrowserView):
                 del args['review_state']
         catalog = getToolByName(context, 'portal_catalog')
         brains = catalog.searchResults(**args)
-        eventsFilter = queryAdapter( self.context, ISolgemaFullcalendarEditableFilter )
-        editpaths = eventsFilter.filterEvents(args)
 
         for filt in filters:
             if isinstance(filt['values'], str):
                 brains = [ a for a in brains if not getattr(a, filt['name']) ]
             else:
                 brains = [ a for a in brains if not getattr(a, filt['name']) or len([b for b in self.convertAsList(getattr(a, filt['name'])) if b in filt['values']])>0 ]
-                
-        result = []
-        member = self.context.portal_membership.getAuthenticatedMember()
-        memberid = member.id
-        criteriaItems = getCriteriaItems(self.context, self.request)
-        for brain in brains:
-            if memberid in brain.Creator:
-                editable = True
-            else:
-                editable = False
-            if brain.getURL() in editpaths:
-                editable = True
-            else:
-                editable = False
-            if brain.end - brain.start > 1.0:
-                allday = True
-            else:
-                allday = False
-            if getattr(brain, 'SFAllDay', None) in [False,True]:
-                allday = brain.SFAllDay
-            copycut = ''
-            if self.copyDict and brain.getPath() == self.copyDict['url']:
-                copycut = self.copyDict['op'] == 1 and ' event_cutted' or ' event_copied'
-            typeClass = ' type-'+brain.portal_type
-            colorIndex = getColorIndex(self.context, self.request, brain=brain)
-            result.append({"id": "UID_%s" % (brain.UID), 
-                           "title": brain.Title, 
-                           "description": brain.Description,
-                           "start": brain.start.rfc822(),
-                           "end": brain.end.rfc822(),
-                           "url": brain.getURL(),
-                           "editable": editable,
-                           "allDay": allday, 
-                           "className": "contextualContentMenuEnabled state-" + str(brain.review_state) + (editable and " editable" or "")+copycut+typeClass+colorIndex})
+
+        topicEventsDict = getMultiAdapter((self.context, self.request), ISolgemaFullcalendarTopicEventDict)
+        result = topicEventsDict.createDict(brains, args)
         return json.dumps(result, sort_keys=True)
+
+class SolgemaFullcalendarColorsCss(BrowserView):
+    """Solgema Fullcalendar Javascript variables"""
+
+    implements(ISolgemaFullcalendarColorsCss)
+
+    def __init__(self, context, request):
+        self.context = context
+        self.request = request
+        self.calendar = ISolgemaFullcalendarProperties(aq_inner(context), None)
+
+    def generateCSS(self):
+        colorsDict = self.calendar.queryColors
+        criterias = listBaseQueryTopicCriteria(self.context)
+        css = ''
+        for criteria in criterias:
+            field = criteria.Field()
+            fieldid = str(field)
+            if not colorsDict.has_key(fieldid):
+                continue
+            selectedItems = []
+            if criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion']:
+                selectedItems = criteria.getCriteriaItems()[0][1]['query']
+            elif criteria.meta_type == 'ATPortalTypeCriterion':
+                selectedItems = criteria.getCriteriaItems()[0][1]
+            for i in range(len(selectedItems)):
+                cValName = selectedItems[i]
+                if not colorsDict[fieldid].has_key(cValName):
+                    continue
+                color = colorsDict[fieldid][cValName]
+                if color:
+                    css += '#calendar div.fc-event.%scolorIndex-%s {\n' % (fieldid, str(i))
+                    css += '    border:1px solid %s;\n' % (str(color))
+                    css += '}\n\n'
+                    css += '#calendar div.fc-event.%scolorIndex-%s a,\n' % (fieldid, str(i))
+                    css += '#calendar div.fc-event.%scolorIndex-%s a .fc-event-time {\n' % (fieldid, str(i))
+                    css += '    background-color: %s;\n' % (str(color))
+                    css += '}\n\n'
+                    css += 'label.%scolorIndex-%s {\n' % (fieldid, str(i))
+                    css += '    color: %s;\n' % (str(color))
+                    css += '}\n\n'
+        return css
+
