@@ -14,7 +14,7 @@ PMF = MessageFactory('plone')
 import datetime
 from zope.component.interface import provideInterface
 from zope.component.tests import ITestType
-
+from zope.schema.interfaces import IDict
 from plone.app.vocabularies.catalog import SearchableTextSource, SearchableTextSourceBinder
 
 from zope.app.publisher.interfaces.browser import IBrowserMenu
@@ -40,6 +40,9 @@ class ISolgemaFullcalendarLayer(IDefaultPloneLayer):
 class ISolgemaFullcalendarView(Interface):
     """Solgema Fullcalendar View interface"""
 
+class ISolgemaFullcalendarColorsCss(ISolgemaFullcalendarView):
+    """Css generated for colors"""
+
 class ISolgemaFullcalendarJS(ISolgemaFullcalendarView):
     """Solgema Fullcalendar View interface for JS Vars"""
 
@@ -127,6 +130,23 @@ class CustomSearchableTextSourceBinder(SearchableTextSourceBinder):
         return CustomSearchableTextSource(context, base_query=self.query.copy(),
                                     default_query=self.default_query)
 
+class ICustomUpdatingDict(IDict):
+    """Interface for CustomUpdatingDict ( Colors Field )"""
+
+class CustomUpdatingDict(schema.Dict):
+
+    implements(ICustomUpdatingDict)
+
+    def set(self, object, value):
+        if self.readonly:
+            raise TypeError("Can't set values on read-only fields "
+                            "(name=%s, class=%s.%s)"
+                            % (self.__name__,
+                               object.__class__.__module__,
+                               object.__class__.__name__))
+        oldvalue = self.get(object)
+        setattr(object, self.__name__, oldvalue.update(value))
+
 class ISolgemaFullcalendarProperties(Interface):
     """An interface for specific calendar content stored in the object"""
 
@@ -193,6 +213,11 @@ class ISolgemaFullcalendarProperties(Interface):
                                   value_type = schema.Choice( title = _(u"label_availableCriterias"), source = "solgemafullcalendar.availableCriterias"),
                                   default = [] )
 
+    queryColors = CustomUpdatingDict( title = _(u"label_queryColors"),
+                                  required = False,
+                                  description = _(u"help_queryColors"),
+                                  default = {} )
+
     displayUndefined = schema.Bool( title=_(u"label_displayUndefined"),
                                   required = False,
                                   description = _(u"help_displayUndefined"),
@@ -215,6 +240,12 @@ class ISolgemaFullcalendarEditableFilter(Interface):
     def filterEvents(self, args):
         """custom method that filters and returns list of paths of the events that can be edited"""
 
+class ISolgemaFullcalendarEventDict(Interface):
+    """Return a friendly calendar dict for events"""
+
+class ISolgemaFullcalendarTopicEventDict(Interface):
+    """Return a friendly calendar dict for events in topic query"""
+
 class ISolgemaFullcalendarMarker(Interface):
     """A marker for items that can be displayed as solgemafullcalendar_view"""
 
